@@ -359,6 +359,15 @@ def indicators_factory() -> List[Indicator]:
                     in_use_backtest=True,
                     processing=ProcessingFunction(date=find_last_true_run_start),
                 ),
+                Signal(
+                    name="SMA_50_BELOW_SMA_200",
+                    description="SMA 50 is below SMA 200",
+                    type_info="Overbought",
+                    type=Optional[date],
+                    function=lambda d: d.SMA_50 < d.SMA_200,
+                    in_use_backtest=True,
+                    processing=ProcessingFunction(date=find_last_true_run_start),
+                ),
                 Signal(
                     name="PRICE_ABOVE_SMA_50",
                     description="Price is above SMA 50",
@@ -368,6 +377,15 @@ def indicators_factory() -> List[Indicator]:
                     in_use_backtest=True,
                     processing=ProcessingFunction(date=find_last_true_run_start),
                 ),
+                Signal(
+                    name="PRICE_BELOW_SMA_50",
+                    description="Price is below SMA 50",
+                    type_info="Overbought",
+                    type=Optional[date],
+                    function=lambda d: d.SMA_50 > d.CLOSE,
+                    in_use_backtest=True,
+                    processing=ProcessingFunction(date=find_last_true_run_start),
+                ),
             ],
         ),
         Indicator(
