@@ -6,13 +6,13 @@ from typing import Optional, List, Type, Dict, Any
 
 import pandas as pd
 import streamlit as st
+
 import streamlit_pydantic as sp
 from bearish.models.base import Ticker  # type: ignore
 from bearish.models.price.prices import Prices  # type: ignore
 from bearish.models.query.query import AssetQuery, Symbols  # type: ignore
 from streamlit_file_browser import st_file_browser  # type: ignore
 
-from bullish.analysis.backtest import BacktestResults
 from bullish.analysis.industry_views import get_industry_comparison_data
 from bullish.analysis.predefined_filters import PredefinedFilters
 from bullish.database.crud import BullishDb
@@ -27,7 +27,7 @@ from bullish.analysis.filter import (
     GeneralFilter,
     TechnicalAnalysisFilters,
 )
-from bullish.jobs.tasks import update, news, analysis, backtest_signals
+from bullish.jobs.tasks import update, news, analysis, initialize
 from pydantic import BaseModel
 
 from bullish.utils.checks import (
@@ -39,7 +39,7 @@ from bullish.utils.checks import (
 CACHE_SHELVE = "user_cache"
 DB_KEY = "db_path"
 
-st.set_page_config(layout="wide")
+st.set_page_config(page_title="Bullish", page_icon="💰", layout="wide")
 logger = logging.getLogger(__name__)
 
 
@@ -91,14 +91,16 @@ def on_table_select() -> None:
     prices = db.read_series(query, months=24)
     data = Prices(prices=prices).to_dataframe()
     dates = db.read_dates(symbol)
+    subject = db.read_subject(symbol)
     industry_data = get_industry_comparison_data(db, data, "Mean", industry, country)
 
     fig = plot(data, symbol, dates=dates, industry_data=industry_data)
 
     st.session_state.ticker_figure = fig
+    st.session_state.ticker_news = subject
 
 
-@st.dialog("🔑  Provide database file to continue")
+@st.dialog("🔑  Select database file to continue")
 def dialog_pick_database() -> None:
     current_working_directory = Path.cwd()
     event = st_file_browser(
@@ -214,17 +216,6 @@ def jobs() -> None:
 
             st.success("Data update job has been enqueued.")
             st.rerun()
-    with st.expander("Update analysis"):
-        if st.button("Update analysis"):
-            analysis(st.session_state.database_path, job_type="Update analysis")
-            st.success("Data update job has been enqueued.")
-            st.rerun()
-    with st.expander("Compute backtest signals"):
-        if st.button("Compute backtest signals"):
-            backtest_signals(
-                st.session_state.database_path, job_type="backtest signals"
-            )
-            st.rerun()
 
 
 @st.dialog("📥  Load", width="large")
@@ -243,33 +234,28 @@ def load() -> None:
 
 @st.dialog("🔍  Filter", width="large")
 def filter() -> None:
+    with st.container(), st.expander("Predefined filters"):
+        predefined_filter_names = PredefinedFilters().get_predefined_filter_names()
+        option = st.selectbox(
+            "Select a predefined filter",
+            ["", *predefined_filter_names],
+        )
+        if option:
+            data_ = PredefinedFilters().get_predefined_filter(option)
+            st.session_state.filter_query.update(data_)
     with st.container():
-        column_1, column_2 = st.columns(2)
-        with column_1:
-            # TODO: order here matters
-            with st.expander("Predefined filters"):
-                predefined_filter_names = (
-                    PredefinedFilters().get_predefined_filter_names()
-                )
-                option = st.selectbox(
-                    "Select a predefined filter",
-                    ["", *predefined_filter_names],
-                )
-                if option:
-                    data_ = PredefinedFilters().get_predefined_filter(option)
-                    st.session_state.filter_query.update(data_)
-            with st.expander("Technical Analysis"):
-                for filter in TechnicalAnalysisFilters:
-                    with st.expander(filter._description):  # type: ignore
-                        build_filter(filter, st.session_state.filter_query)
 
-        with column_2:
-            with st.expander("Fundamental Analysis"):
-                for filter in FundamentalAnalysisFilters:
-                    with st.expander(filter._description):  # type: ignore
-                        build_filter(filter, st.session_state.filter_query)
-            with st.expander("General filter"):
-                build_filter(GeneralFilter, st.session_state.filter_query)
+        with st.expander("Technical Analysis"):
+            for filter in TechnicalAnalysisFilters:
+                with st.expander(filter._description):  # type: ignore
+                    build_filter(filter, st.session_state.filter_query)
+
+        with st.expander("Fundamental Analysis"):
+            for filter in FundamentalAnalysisFilters:
+                with st.expander(filter._description):  # type: ignore
+                    build_filter(filter, st.session_state.filter_query)
+        with st.expander("General filter"):
+            build_filter(GeneralFilter, st.session_state.filter_query)
 
     if st.button("🔍 Apply"):
         query = FilterQuery.model_validate(st.session_state.filter_query)
@@ -278,6 +264,7 @@ def filter() -> None:
                 st.session_state.database_path
             ).read_filter_query(query)
             st.session_state.ticker_figure = None
+            st.session_state.ticker_news = None
             st.session_state.filter_query = {}
             st.session_state.query = query
             st.rerun()
@@ -297,8 +284,87 @@ def dialog_plot_figure() -> None:
         unsafe_allow_html=True,
     )
     st.html("<span class='big-dialog'></span>")
+    if st.session_state.ticker_news:
+        st.markdown(
+            f"""
+            <div class="news-hover" >
+              📰 <span class="label">News</span>
+              <div class="tooltip">
+                <h2>Date: {st.session_state.ticker_news.news_date.date()}</h2>
+                <h2>Price targets</h2>
+                <p>High price target: {st.session_state.ticker_news.high_price_target}</p>
+                <p>Low price target: {st.session_state.ticker_news.low_price_target}</p>
+                <h2>Recommendation: {st.session_state.ticker_news.recommendation}</h2>
+                <h2>Consensus: {st.session_state.ticker_news.consensus}</h2>
+                <h2>Explanation & reasons</h2>
+                <p>{st.session_state.ticker_news.explanation}</p>
+                <p>{st.session_state.ticker_news.reason}</p>
+                <h2>News summaries</h2>
+                {st.session_state.ticker_news.to_news()}
+              </div>
+            </div>    
+            <style>
+              /* Hover target (fixed top-left) */
+              .news-hover {{
+                position: absolute;
+                left: 1rem;
+                display: inline-flex;
+                align-items: center;
+                gap: .4rem;
+                font-size: 1.7rem;       /* big label */
+                font-weight: 600;
+                color: #333;
+                cursor: pointer;
+                user-select: none;
+                z-index: 1100;
+              }}    
+              /* Tooltip bubble */
+              .news-hover .tooltip {{
+                position: absolute;
+                top: 110%;               /* below the label */
+                left: 0;
+                width: 840px;
+                max-height: 620px;
+                overflow-y: auto;
+                background: #222;
+                color: #fff;
+                padding: 1.2rem;
+                border-radius: 10px;
+                font-size: .95rem;
+                line-height: 1.45;
+                box-shadow: 0 8px 20px rgba(0,0,0,.4);
+                opacity: 0;
+                visibility: hidden;
+                transition: opacity .25s ease;
+              }}
+              .news-hover .tooltip hr {{
+                border: none;
+                border-top: 1px solid #444;
+                margin: 1rem 0;
+              }}    
+              /* Show tooltip on hover or keyboard focus */
+              .news-hover:hover .tooltip,
+              .news-hover:focus-within .tooltip {{
+                opacity: 1;
+                visibility: visible;
+              }}
+              /* Little arrow under the bubble */
+              .news-hover .tooltip::after {{
+                content: "";
+                position: absolute;
+                top: -10px;
+                left: 20px;
+                border: 10px solid transparent;
+                border-top-color: #222;
+              }}
+            </style>
+            """,
+            unsafe_allow_html=True,
+        )
+
     st.plotly_chart(st.session_state.ticker_figure, use_container_width=True)
     st.session_state.ticker_figure = None
+    st.session_state.ticker_news = None
 
 
 @st.dialog("⭐ Save filtered results")
@@ -348,8 +414,13 @@ def main() -> None:
 
     if st.session_state.database_path is None:
         dialog_pick_database()
+        initialize(
+            database_path=st.session_state.database_path,
+            job_type="Initialize",
+        )
     bearish_db_ = bearish_db(st.session_state.database_path)
-    charts_tab, jobs_tab, backtests = st.tabs(["Charts", "Jobs", "Backtests"])
+
+    charts_tab, jobs_tab = st.tabs(["Charts", "Jobs"])
     if "data" not in st.session_state:
         st.session_state.data = load_analysis_data(bearish_db_)
 
@@ -400,12 +471,6 @@ def main() -> None:
             use_container_width=True,
             hide_index=True,
         )
-    with backtests:
-        results = bearish_db_.read_many_backtest_results()
-        backtest_results = BacktestResults(results=results)
-        with st.container():
-            figure = backtest_results.figure()
-            st.plotly_chart(figure)
 
 
 if __name__ == "__main__":
